#!/usr/bin/python3

"""Produce a "sorted" list of maildir paths based on subdirs."""

from __future__ import print_function

import os
from pathlib import Path
import sys


IGNORED_DIRS = {
    'drafts',
    'outbox',
    'templates',
    '.inbox.directory',
}
MAILDIR_DIRS = {
    'cur', 'new', 'tmp',
}


def find_dirs(topdir, ignored):
    """Walk the subdirs following the KDE layout."""
    for d in sorted(topdir.iterdir()):
        if d.name in MAILDIR_DIRS:
            continue

        if d in ignored:
            continue
        if not d.is_symlink():
            if (d / 'cur').is_dir():
                yield d
                subdir = topdir / f'.{d.name}.directory'
                if subdir not in ignored and subdir.is_dir():
                    yield from find_dirs(subdir, ignored)


def main(argv):
    maildir = Path('~/.mail/').expanduser()
    ignored = {maildir / x for x in IGNORED_DIRS}

    results = find_dirs(maildir, ignored)
    print(' '.join(f'"{x}"' for x in results))
    return 0


if __name__ == '__main__':
    sys.exit(main(sys.argv[1:]))
